__all__ = ['InputValidator']

class InputValidator:
    @staticmethod
    def getEmailRegular(): ...
    @staticmethod
    def getUsernameRegular(): ...
    @staticmethod
    def getPasswordRegular(): ...
    @staticmethod
    def getPhoneRegular(): ...
    @staticmethod
    def validate(input_str, pattern): ...
